@@ -22,7 +22,9 @@ from atomate2 import SETTINGS
 from atomate2.common.files import get_zfile
 from atomate2.common.schemas.math import Vector3D
 from atomate2.utils.file_client import FileClient
+from atomate2.utils.path import strip_hostname
 from atomate2.vasp.jobs.base import BaseVaspMaker
+from atomate2.vasp.jobs.core import HSEBSMaker, NonSCFMaker
 from atomate2.vasp.sets.base import VaspInputSetGenerator
 from atomate2.vasp.sets.core import (
     HSEBSSetGenerator,
@@ -44,7 +46,7 @@ __all__ = [
 
 
 @dataclass
-class DenseUniformMaker(BaseVaspMaker):
+class DenseUniformMaker(NonSCFMaker):
     """
     Maker to perform a dense uniform non-self consistent field calculation.
 
@@ -66,13 +68,16 @@ class DenseUniformMaker(BaseVaspMaker):
         Keyword arguments that will get passed to :obj:`.should_stop_children`.
     write_additional_data : dict
         Additional data to write to the current directory. Given as a dict of
-        {filename: data}.
+        {filename: data}. Note that if using FireWorks, dictionary keys cannot contain
+        the "." character which is typically used to denote file extensions. To avoid
+        this, use the ":" character, which will automatically be converted to ".". E.g.
+        ``{"my_file:txt": "contents of the file"}``.
     """
 
     name: str = "dense uniform"
     input_set_generator: VaspInputSetGenerator = field(
         default_factory=lambda: NonSCFSetGenerator(
-            mode="uniform", reciprocal_density=1000
+            mode="uniform", reciprocal_density=1000, user_incar_settings={"LWAVE": True}
         )
     )
 
@@ -104,7 +109,10 @@ class StaticDeformationMaker(BaseVaspMaker):
         Keyword arguments that will get passed to :obj:`.should_stop_children`.
     write_additional_data : dict
         Additional data to write to the current directory. Given as a dict of
-        {filename: data}.
+        {filename: data}. Note that if using FireWorks, dictionary keys cannot contain
+        the "." character which is typically used to denote file extensions. To avoid
+        this, use the ":" character, which will automatically be converted to ".". E.g.
+        ``{"my_file:txt": "contents of the file"}``.
     """
 
     name: str = "static deformation"
@@ -143,7 +151,10 @@ class HSEStaticDeformationMaker(BaseVaspMaker):
         Keyword arguments that will get passed to :obj:`.should_stop_children`.
     write_additional_data : dict
         Additional data to write to the current directory. Given as a dict of
-        {filename: data}.
+        {filename: data}. Note that if using FireWorks, dictionary keys cannot contain
+        the "." character which is typically used to denote file extensions. To avoid
+        this, use the ":" character, which will automatically be converted to ".". E.g.
+        ``{"my_file:txt": "contents of the file"}``.
     """
 
     name: str = "static deformation"
@@ -156,7 +167,7 @@ class HSEStaticDeformationMaker(BaseVaspMaker):
 
 
 @dataclass
-class HSEDenseUniformMaker(BaseVaspMaker):
+class HSEDenseUniformMaker(HSEBSMaker):
     """
     Maker to perform a dense uniform non-self consistent field calculation.
 
@@ -178,7 +189,10 @@ class HSEDenseUniformMaker(BaseVaspMaker):
         Keyword arguments that will get passed to :obj:`.should_stop_children`.
     write_additional_data : dict
         Additional data to write to the current directory. Given as a dict of
-        {filename: data}.
+        {filename: data}. Note that if using FireWorks, dictionary keys cannot contain
+        the "." character which is typically used to denote file extensions. To avoid
+        this, use the ":" character, which will automatically be converted to ".". E.g.
+        ``{"my_file:txt": "contents of the file"}``.
     """
 
     name: str = "dense uniform"
@@ -186,6 +200,7 @@ class HSEDenseUniformMaker(BaseVaspMaker):
         default_factory=lambda: HSEBSSetGenerator(
             mode="uniform_dense",
             zero_weighted_reciprocal_density=1000,
+            user_incar_settings={"LWAVE": True},
         )
     )
 
@@ -238,11 +253,11 @@ def run_amset_deformations(
         static_job = static_deformation_maker.make(
             deformed_structure, prev_vasp_dir=prev_vasp_dir
         )
-        static_job.name += f" {i + 1}/{len(deformations)}"
+        static_job.append_name(f" {i + 1}/{len(deformations)}")
         statics.append(static_job)
 
         # extract the outputs we want (only the dir name)
-        outputs.append(static_job.dir_name)
+        outputs.append(static_job.output.dir_name)
 
     static_flow = Flow(statics, outputs)
     return Response(replace=static_flow)
@@ -290,6 +305,9 @@ def calculate_deformation_potentials(
     bands_str = ".".join(",".join([str(idx + 1) for idx in b]) for b in ibands)
     symprec_str = "N" if symprec is None else str(symprec)
 
+    # TODO: Handle hostnames properly
+    bulk_dir = strip_hostname(bulk_dir)
+    deformation_dirs = [strip_hostname(d) for d in deformation_dirs]
     args = [
         bulk_dir,
         *deformation_dirs,
@@ -301,7 +319,7 @@ def calculate_deformation_potentials(
 
     # TODO: Store some information about the deformation potentials, e.g., values
     #   at CBM and VBM?
-    return {"dir_name": Path.cwd(), "log": result.output}
+    return {"dir_name": str(Path.cwd()), "log": result.output}
 
 
 @job
@@ -334,16 +352,15 @@ def calculate_polar_phonon_frequency(
         - "frequencies" (list[float]): A list of all phonon frequencies.
         - "weights" (list[float]): A list of weights for the frequencies.
     """
-    frequencies = np.array(frequencies)
-    eigenvectors = np.array(eigenvectors)
-    born_effective_charges = np.array(born_effective_charges)
-
     effective_frequency, weights = calculate_effective_phonon_frequency(
-        frequencies, eigenvectors, born_effective_charges, structure
+        np.array(frequencies),
+        np.array(eigenvectors),
+        np.array(born_effective_charges),
+        structure,
     )
     return {
         "frequency": effective_frequency,
-        "weights": weights,
+        "weights": weights.tolist(),
         "frequencies": frequencies,
     }
 
@@ -370,19 +387,25 @@ def generate_wavefunction_coefficients(dir_name: str):
           file. Given as a tuple of one or two lists (one for each spin channel).
           The bands indices are zero indexed.
     """
-    files = FileClient().listdir(dir_name)
-    vasprun_file = get_zfile(files, "vasprun.xml")
-    wavecar_file = get_zfile(files, "WAVECAR")
+    dir_name = strip_hostname(dir_name)  # TODO: Handle hostnames properly.
+    fc = FileClient()
+    files = fc.listdir(dir_name)
+    vasprun_file = Path(dir_name) / get_zfile(files, "vasprun.xml")
+    wavecar_file = Path(dir_name) / get_zfile(files, "WAVECAR")
 
-    args = [
-        f"--wavecar={wavecar_file}",
-        f"--vasprun={vasprun_file}",
-    ]
+    # wavecar can't be gzipped, so copy it to current directory and unzip it
+    fc.copy(wavecar_file, wavecar_file.name)
+    fc.gunzip(wavecar_file.name)
+
+    args = ["--wavecar=WAVECAR", f"--vasprun={vasprun_file}"]
     runner = CliRunner()
     result = runner.invoke(wave, args, catch_exceptions=False)
     ibands = _extract_ibands(result.output)
 
-    return {"dir_name": Path.cwd(), "log": result.output, "ibands": ibands}
+    # remove WAVECAR from current directory
+    fc.remove("WAVECAR")
+
+    return {"dir_name": str(Path.cwd()), "log": result.output, "ibands": ibands}
 
 
 def _extract_ibands(log: str) -> tuple[list[int], ...]:
@@ -407,12 +430,12 @@ def _extract_ibands(log: str) -> tuple[list[int], ...]:
     for i in range(len(result_splits)):
         if "Including bands" in result_splits[i]:
             # non-spin polarised result system
-            min_band, max_band = result_splits[i].split(" ")[-1].split("-")
+            min_band, max_band = result_splits[i].split(" ")[-1].split("—")
             return (list(range(int(min_band) - 1, int(max_band))),)
 
         if "Including:" in result_splits[i]:
-            amin_band, amax_band = result_splits[i + 1].split(" ")[-1].split("-")
-            bmin_band, bmax_band = result_splits[i + 2].split(" ")[-1].split("-")
+            amin_band, amax_band = result_splits[i + 1].split(" ")[-1].split("—")
+            bmin_band, bmax_band = result_splits[i + 2].split(" ")[-1].split("—")
             aibands = list(range(int(amin_band) - 1, int(amax_band)))
             bibands = list(range(int(bmin_band) - 1, int(bmax_band)))
 
